Learn R Programming

ssaBSS (version 0.1.1)

ssaBSS-package: Stationary Subspace Analysis

Description

Stationary subspace analysis (SSA) is a blind source separation (BSS) variant where stationary components are separated from non-stationary components. Several SSA methods for multivariate time series are provided here (Flumian et al. (2021); Hara et al. (2010) <doi:10.1007/978-3-642-17537-4_52>) along with functions to simulate time series with time-varying variance and autocovariance (Patilea and Raïssi(2014) <doi:10.1080/01621459.2014.884504>).

Arguments

Author

Markus Matilainen, Léa Flumian, Klaus Nordhausen, Sara Taskinen

Maintainer: Markus Matilainen <markus.matilainen@outlook.com>

Details

Package:ssaBSS
Type:Package
Version:0.1.1
Date:2022-12-01
License:GPL (>= 2)

This package contains functions for identifying different types of nonstationarity

  • SSAsir -- SIR type function for mean non-stationarity identification

  • SSAsave -- SAVE type function for variance non-stationarity identification

  • SSAcor -- Function for identifying changes in autocorrelation

  • ASSA -- ASSA: Analytic SSA for identification of nonstationarity in mean and variance.

  • SSAcomb -- Combination of SSAsir, SSAsave, and SSAcor using joint diagonalization

The package also contains function rtvvar to simulate a time series with time-varying variance (TV-VAR), and function rtvAR1 to simulate a time series with time-varying autocovariance (TV-AR1).

References

Flumian L., Matilainen M., Nordhausen K. and Taskinen S. (2021) Stationary subspace analysis based on second-order statistics. Submitted. Available on arXiv: https://arxiv.org/abs/2103.06148

Hara S., Kawahara Y., Washio T. and von Bünau P. (2010). Stationary Subspace Analysis as a Generalized Eigenvalue Problem, Neural Information Processing. Theory and Algorithms, Part I, pp. 422-429.

Patilea V. and Raïssi H. (2014) Testing Second-Order Dynamics for Autoregressive Processes in Presence of Time-Varying Variance, Journal of the American Statistical Association, 109 (507), 1099-1111.