Class 'ssabss' (blind source separation in stationary subspace analysis) with methods plot, screeplot (prints a screeplot of an object of class 'ssabss') and ggscreeplot (prints a screeplot of an object of class 'ssabss' using package ggplot2).
The class 'ssabss' also inherits methods from the class 'bss' in package JADE: for extracting the components (bss.components), for plotting the components (plot.bss), for printing (print.bss), and for extracting the coefficients (coef.bss).
# S3 method for ssabss
plot(x, ...)# S3 method for ssabss
screeplot(x, type = c("lines", "barplot"), xlab = "Number of components",
ylab = NULL, main = paste("Screeplot for", x$method),
pointsize = 4, breaks = 1:length(x$D), color = "red", ...)
# S3 method for ssabss
ggscreeplot(x, type = c("lines", "barplot"), xlab = "Number of components",
ylab = NULL, main = paste("Screeplot for", x$method),
pointsize = 4, breaks = 1:length(x$D), color = "red", ...)
An object of class 'ssabss'.
Type of screeplot. Choices are "lines" (default) and "barplot".
Label for x-axis. Default is "Number of components".
Label for y-axis. Default is "Sum of pseudo eigenvalues" if method is SSAcomb and "Eigenvalues" otherwise.
Title of the plot. Default is "Screeplot for ...", where ... denotes for the name of the method used.
Size of the points in the plot (for type = "lines" only). Default is 4.
Breaks and labels for the x-axis. Default is from 1 to the number of series by 1.
Color of the line (if type = "lines") or bar (if type = "barplot"). Default is red.
Further arguments to be passed to or from methods.
Markus Matilainen
A screeplot can be used to determine the number of interesting components. For SSAcomb it plots the sum of pseudo eigenvalues and for other methods it plots the eigenvalues.
ASSA, SSAsir, SSAsave, SSAcor, SSAcomb, JADE, ggplot2